Read HSE data deprecated
read_hse.RdReads and does basic cleaning of a selected year of the Health Survey for England.
Usage
read_hse(year, root = c("X:/", "/Volumes/Shared/"))
read_hse.RdReads and does basic cleaning of a selected year of the Health Survey for England.
read_hse(year, root = c("X:/", "/Volumes/Shared/"))