Quitting smoking experimental
smk_quit.RdCleans the data on the motivation to quit smoking and the use of support.
Value
Returns an updated data table with:
giveup_smk - whether a current smoker wants to quit smoking (yes, no).
Examples
if (FALSE) { # \dontrun{
data <- read_2001()
data <- smk_quit(data)
} # }