Multinomial model of number of kids in the household 2012-2014
impute_kids_model.RdTo impute the missing data for number of kids in the household for years 2015+

impute_kids_model.RdTo impute the missing data for number of kids in the household for years 2015+