Fills missing values with subgroup mean value
impute_mean.RdReplaces any values < 0 with NA, calculates the subgroup mean, then replaces missing values with the subgroup mean.
Usage
impute_mean(
data,
var_names,
remove_zeros = FALSE,
strat_vars = c("year", "sex", "imd_quintile", "age_cat")
)Value
Returns an updated version of data in which the variables specified have had their missing values imputed with the subgroup means.
Details
If not all NAs can be imputed with the fine scale starting amount of stratification, imputation is attempted again, removing the stratification variable specified last.
Examples
if (FALSE) { # \dontrun{
data <- read_2001()
data <- clean_age(data)
data <- clean_demographic(data)
data <- impute_mean(data, var_names = c("d7many"))
} # }